@@ -651,7 +651,7 @@ class _CustomMLP(nn.Module):
                 raise ValueError(f"Wrong name {activation_type} for activation function.")
             layers.append(nn.Dropout(self.dropout_p))
             the_rest = self.n_hidden_units_list[1:]
-            for idx in range(len(the_rest-1)):
+            for idx in range(len(the_rest)-1):
                 layers.append(nn.Linear(the_rest[idx], the_rest[idx+1]))
                 if self.bn:
                     layers.append(nn.BatchNorm1d(num_features=self.the_rest[idx+1]))
@@ -694,10 +694,6 @@ class CustomMLP(BaseNet):
 
     We can define n_hidden_units for all hidden layers with a list of integers.
 
-    The hyperparameters that are only in CustomMLP are 'layer_{n}_dim's (for all hidden layers). 
-
-    
-
     Args:
         
         dims (Union[int, Tuple[int]]): The dimension of the data. e.g., 4, (1,8,8)
@@ -759,10 +755,6 @@ class CustomMLP(BaseNet):
                 hparams.update({argument : default})
         #set default for model-agnostic hyperparameters
         set_default_parameters(hparams)
-        # add hparams : layer_n_dim
-        for idx in range(1, len(hparams['n_hidden_units_list'])+1):
-            key_str = 'layer_' + str(idx) +'_dim'
-            hparams.update({key_str : hparams['n_hidden_units_list'][idx-1]}) 
         # save information of **hparams to self.hparams.
         self.save_hyperparameters(*hparams)
         # n_hidden_units_list
@@ -778,10 +770,6 @@ class CustomMLP(BaseNet):
             **hparams
         )
 
-        # sanity check. Check if right arguments are declared.
-        for key in hparams.keys():
-            if key not in entire_keys:
-                raise ValueError(f'Wrong argument {key} is passed to the model.')
         self.model = _CustomMLP(dims=dims, n_classes=n_classes, sample_weight=sample_weight, **hparams)
 
     def forward(self, X):
